package convertquery

// Service is a model for the convertquery use case
type Service struct {
}

// NewService creates a new convertquery service
func NewService() *Service {
	return &Service{}
}

// Struct used for JSON conversion of the incoming byte array
type parsedJSON struct {
	Return    returnStruct
	Entities  []entityStruct
	Relations []relationStruct
}

// returnStruct holds the indices of the entities and relations that need to be returned
type returnStruct struct {
	Entities  []int
	Relations []int
}

// entityStruct encapsulates a single entity with its corresponding constraints
type entityStruct struct {
	Type        string
	Constraints []constraintStruct
}

// relationStruct encapsulates a single relation with its corresponding constraints
type relationStruct struct {
	Type        string
	EntityFrom  int
	EntityTo    int
	Depth       searchDepthStruct
	Constraints []constraintStruct
}

// searchDepthStruct holds the range of traversals for the relation
type searchDepthStruct struct {
	Min int
	Max int
}

/*
constraintStruct holds the information of the constraint

Constraint datatypes
	text     MatchTypes: exact/contains/startswith/endswith
	number   MatchTypes: GT/LT/EQ
	bool     MatchTypes: EQ/NEQ
*/
type constraintStruct struct {
	Attribute string
	Value     string
	DataType  string
	MatchType string
}
